#
# spec file for package sfcgal
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Ioda-Net Sàrl, Charmoille, Switzerland. Bruno Friedmann (tigerfoot)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define source_name SFCGAL
%define _libname    libSFCGAL2
%define _soversion  2
# while upstream https://gitlab.com/Oslandia/SFCGAL/-/issues/259
# and https://gitlab.com/Oslandia/SFCGAL/-/issues/258 are pending.
# this force postgis ix86 to be build without sfcgal.
ExcludeArch:    %{ix86}
%ifarch %{ix86} x86_64
%define withosgd 1
BuildRequires:  pkgconfig(openscenegraph)
%else
# openscenegraph not available for
# s390x ppc64le ppc64 aarch64 armv7l
# dummy
%define withosgd 0
%endif
Name:           sfcgal
Version:        2.0.0
Release:        1.3
Summary:        C++ wrapper library around CGAL
License:        LGPL-2.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://sfcgal.gitlab.io/SFCGAL/
Source0:        https://gitlab.com/sfcgal/SFCGAL/-/archive/v%{version}/SFCGAL-v%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gmp-devel
BuildRequires:  lapack-devel
BuildRequires:  libboost_chrono-devel >= 1.72
BuildRequires:  libboost_filesystem-devel >= 1.72
BuildRequires:  libboost_headers-devel >= 1.72
BuildRequires:  libboost_program_options-devel >= 1.72
BuildRequires:  libboost_serialization-devel >= 1.72
BuildRequires:  libboost_system-devel >= 1.72
BuildRequires:  libboost_test-devel >= 1.72
BuildRequires:  libboost_thread-devel >= 1.72
BuildRequires:  libboost_timer-devel >= 1.72
BuildRequires:  libcgal-devel >= 5.6
BuildRequires:  libstdc++-devel
BuildRequires:  llvm-clang
BuildRequires:  memory-constraints
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cunit)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libecpg) >= 10
BuildRequires:  pkgconfig(libecpg_compat) >= 10
BuildRequires:  pkgconfig(libpgtypes) >= 10
BuildRequires:  pkgconfig(libpq) >= 10
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(zlib)

%description
This package contains tools & sample data to test %{_libname}.

%package -n %{_libname}
Summary:        Libraries SFCGAL applications
Group:          Development/Libraries/C and C++
Provides:       libsfcgal%{_soversion}

%description -n %{_libname}
This library  support ISO 19107:2013, OGC Simple Features Access 1.2 for 3D operations.
It provides standard compliant geometry types and operations, that can
be accessed from its C or C++ APIs. PostGIS uses the C API, to expose some
SFCGAL's functions in spatial databases (cf. PostGIS manual).

Geometry coordinates have an exact rational number representation and can
be either 2D or 3D. Among supported geometry types are :

 Points
 LineStrings
 Polygons
 TriangulatedSurfaces
 PolyhedralSurfaces
 GeometryCollections
 Solids

Supported operations include :

 WKT reading and writing with exact rational number representation for coordinates
 Intersection operations and predicates
 Convex hull computation
 Tessellation
 Extrusion
 Area and distance computation
 Minkovski sums
 Contour offsets
 Straight skeleton generations

%package devel
Summary:        Development files and tools for SFCGAL applications
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}

%description devel
Content headers & files to envelopment files for %{_libname}

%prep
%setup -q -n %{source_name}-v%{version}

%build
%limit_build -m 6400
tmpflags="%{optflags} -fPIC -fPIE"
echo "${tmpflags}"
# Desactivate lto (check with upstream)
%define _lto_cflags %{nil}
tmpflags="${tmpflags/-flto=auto}"
%ifarch ppc64 ppc64le
# bypass bug 927268 for PowerPC if clang is used above in place of gcc
tmpflags="${tmpflags/-fstack-protector}"
tmpflags="${tmpflags/-strong}"
%endif
#Remove -fstack-clash-protection added on 42.3 for unknown reason
tmpflags="${tmpflags/-fstack-clash-protection}"

%cmake \
  -DCMAKE_USER_MAKE_RULES_OVERRIDE=OFF \
  -DCMAKE_C_FLAGS="${tmpflags} -Doverride=" \
  -DCMAKE_CXX_FLAGS="${tmpflags} -Doverride=" \
  -DCMAKE_CXX_FLAGS_RELEASE="${tmpflags} -Doverride=" \
  -DCMAKE_BUILD_TYPE="Release" \
  -DCMAKE_GMP_ENABLE_CXX=ON \
  -DSFCGAL_CHECK_VALIDITY=TRUE \
  -DCMAKE_NO_BUILTIN_CHRPATH=ON \
%if %{withosgd}
  -DSFCGAL_WITH_OSG=ON \
%else
  -DSFCGAL_WITH_OSG=OFF \
%endif
  -DSFCGAL_BUILD_EXAMPLES=ON \
  -DSFCGAL_BUILD_TESTS=ON

%cmake_build

%install
%cmake_install

# Work fine only on x86
%ifarch i586 x86_64
%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest ||:
%endif

%post -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig

%files -n %{_libname}
%license LICENSE
%doc README.md AUTHORS NEWS
%{_libdir}/libSFCGAL.so.%{version}
%{_libdir}/libSFCGAL.so.%{_soversion}
%if %{withosgd}
%{_libdir}/libSFCGAL-osg.so.%{version}
%{_libdir}/libSFCGAL-osg.so.%{_soversion}
%endif

%files
%license LICENSE
%doc README.md AUTHORS NEWS
%{_bindir}/example-CGAL-*
%{_bindir}/example-SFCGAL-*
%{_bindir}/unit-test-SFCGAL
%{_bindir}/standalone-regress-test-SFCGAL
%{_bindir}/test-regress-convex_hull
%{_bindir}/test-regress-polygon_triangulator

%files devel
%license LICENSE
%doc README.md AUTHORS NEWS
%{_libdir}/libSFCGAL.so
%if %{withosgd}
%{_libdir}/libSFCGAL-osg.so
%endif
%{_libdir}/pkgconfig/sfcgal.pc
%{_includedir}/SFCGAL
%{_bindir}/sfcgal-config

%changelog
* Thu Mar  6 2025 Bruno Friedmann <bruno@ioda-net.ch>
- update minimum boost to 1.72
- use %%ctest
* Wed Mar  5 2025 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 2.0.0 (2024-10-10):
  + New Features (Feat)
  - !348: Rewrite VTK export like OBJ one (Loïc Bartoletti)
  - !347: Add translate method to C API (Loïc Bartoletti)
  - !345: Add scale method to Transform (Loïc Bartoletti)
  - !344: Add rotate method to Transform (Loïc Bartoletti)
  - !342: Add Buffer3D functionality (Loïc Bartoletti)
  - !341: Add partitioning algorithm using Straight Skeleton (Loïc Bartoletti)
  - !340: Add Minkowski Sum 3D (Loïc Bartoletti)
  - !339: Add a Cylinder (3D) Class (Loïc Bartoletti)
  - !338: Add a Sphere (3D) Class (Loïc Bartoletti)
  - !334: Add OBJ export functionality to SFCGAL (Loïc Bartoletti)
  + Bug Fixes (Fix)
  - !354: Ensure null termination in geometry_as_text functions (sfcgal_capi) (Loïc Bartoletti)
  - !352: Fix test MinkowskiSum3D (Loïc Bartoletti)
  - !351: Fix vcpkg build (Loïc Bartoletti)
  - !349: Fix build for clang18, missing includes (Loïc Bartoletti)
  - !346: Add missing SFCGAL_API for VTK and OBJ headers (exportDll) (Loïc Bartoletti)
  + Improvements (Improve/Update)
  - !374: Add the MultiSolid class to the C API
  - !366: Add missing pre-condition in C API (Raphaël Delhome)
  - !364: Fix warnings and apply clang-tidy fix (Loïc Bartoletti)
  - !358: Improve Buffer3D tests resilience for cross-platform compatibility (Loïc Bartoletti)
  - !337: Improve error message for Straight Skeleton (Loïc Bartoletti)
  - !331: Generalize PolyhedralSurface constructor with template (Loïc Bartoletti)
  - !325: Compatibility with CGAL 6.0 and 5.6 (Sebastien Loriot)
  + Continuous Integration (CI)
  - !356: Matrix test for CGAL 5.6 and 6.0 (Loïc Bartoletti)
  - !355: Disable a flaky test for MinkowskiSum3D in MinGW (Loïc Bartoletti)
  - !353: Always run 'build:debian-docker-image' job (Jean Felder)
  - !333: Use a global variable to define CGAL version (Jean Felder)
  - !329: Allow CGAL 6.0 CI and update CI images (Loïc Bartoletti)
  - !323: Build a debian docker image (Jean Felder)
  + Documentation (Docs)
  - !335: Add an option to build documentation in CMakeLists (Jean Felder)
  - !332: Add pre-commit workflow to the README (Jean Felder)
  + Tests (Tests)
  - !343: Add unit test for Translate (Loïc Bartoletti)
- packaging
  + renew and refresh spec file
  + bump libname and soversion to 2
  + remove upstream merged patch boost1_85.diff
* Mon Apr 29 2024 Dirk Stoecker <opensuse@dstoecker.de>
- fix build with boost 1.85 (boost1_85.diff)
* Tue Jan  9 2024 Bruno Friedmann <bruno@ioda-net.ch>
- Set minimal version for libboost to 1.70 which is required by cgal 5.6
* Tue Jan  9 2024 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.5.1
  * Rewrite and fix visibility algorithm (Loïc Bartoletti)
  * Apply clang-tidy fixes (Loïc Bartoletti)
  * Add vcpkg CI and temporarily disable alpha-shapes for MSVC (Loïc Bartoletti)
- Update to version 1.5.0
  * Add visibility algorithms (Loïc Bartoletti)
  * Straight Skeleton: Add a version with extrusion
  * WKT: Fix triangle code (Loïc Bartoletti)
  * Allow to disable GMPXX (Loïc Bartoletti, Fixes #249 and #252)
  * Add polygon partition (Raphaël Delhome, Loïc Bartoletti)
  * Minor typo correction (Regina Obe, #280)
  * Remove CGAL unit test (Fix #257, Loïc Bartoletti)
  * [C API] Add sfcgal_point_create_from_xyzm and
    sfcgal_point_create_from_xym functions (Loïc Bartoletti #274)
  * Update CI and add FreeBSD, macOs CI (Loïc Bartoletti)
  * Minors fixes (Loïc Bartoletti #269 and #270)
  * Remove useless garden tests (Loïc Bartoletti)
  * Fix SPDX-License-Identifier (Loïc Bartoletti reported
    by Bas Couwenberg #250)
  * NOTE: This is the first release on GitLab/SFCGAL space.
  * SFCGAL has now a dedicated space outside Oslandia one:
    https://gitlab.com/SFCGAL/.
- Packaging
  + Update copyright year
  + Remove previous disable_invalid_cgal_test.patch no more needed
  + Update upstream website and source
  + Update package licence sfcgal is lgpl 2+ not gpl
* Mon Dec  5 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Reduce _constraints to actual lower bound, limit number of
  jobs with memory_per_job and limit_build macro.
- Remove some unused build dependencies.
* Wed Aug  3 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Disable i586 build which failed with both gcc and clang
  https://gitlab.com/Oslandia/SFCGAL/-/issues/258
  https://gitlab.com/Oslandia/SFCGAL/-/issues/259
- Remove unused -D calls
- Lower physical memory constraint to 8GB but keep global memory
  to 16GB
* Tue Jul 26 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Apply upstream fix by removing bundled CGAL test
  see https://gitlab.com/Oslandia/SFCGAL/-/merge_requests/279
* Fri Apr 15 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Use gcc for i586 and limit the number of worker (upstream)
  so we can lower again _constraint.
* Fri Apr  8 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Introduce disable_invalid_cgal_test.patch to disable tests
  failing with CGAL 5.4 on openSUSE.
* Wed Feb 16 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.4.1
  + Add alpha-shapes algorithm
  + Fix build and tests for MSYS2/MinGW
  + Modernize code
  + Remove patches for Boost 1.60.0
  + Fix isPlane3d
  + Fix ST_StraightSkeleton returns degenerate line segments. $
    Add a new parameter `toleranceAbs`
  + Add tests for issues #133 and #153
  + Add ccache, and improve CI
- Packaging
  + Remove FIX_excess-x87-precision.patch upstream has solve the
    problem by using another approach.
  + Remove sfcgal-rpmlintrc not used anymore.
  + Update copyright year
  + Review for submiting to factory
* Mon Nov 22 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.4.0
  + Use officially documented CGAL functions.
    SFCGAL requires CGAL >= 5.3.
  + Fix compilation issue with CGAL 5.3
  + Add sfcgal_full_version with SFCGAL, CGAL and Boost
  + Add include <CGAL/version_macros.h> to build tests with CGAL 4.12
- packaging
  + removed merged patch f929b291d4efe9b780812677fd523d2431519fcf.patch
    upstream_issue#242.patch
  + Adjust CGAL requirement >= 5.3 available onyl for TW
  + Added FIX_excess-x87-precision.patch fixing failed testing
    under i586
* Mon Aug 23 2021 Dirk Stoecker <opensuse@dstoecker.de>
- add f929b291d4efe9b780812677fd523d2431519fcf.patch (Fix compilation issue with CGAL 5.3)
* Tue Apr 20 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix version 1.3.10
  + fix support of CGAL 5.2
  + Add upstream_issue#242.patch to build and execute tests
- spec update license year
* Sun Nov 15 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Renew source with fixed upstream 1.3.9 tar.gz
  + Delete prepare_version_139_missing.patch (merged upstream)
- Packaging remove gcc/clang conditionnal build. clang 11 fix
  building for all arch.
* Sun Oct 11 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.3.9
  + Source moved to gitlab (new development home)
  + Fix build with CGAL 5.1
- Packaging
  + refresh copyright and Requires order with spec-cleaner
  + add prepare_version_139_missing.patch
  + suppress unused fdupe
  + build tests and use them but only on x86 plateform
  + Replace defective clang10 on non x86 plateform
* Tue Jul  7 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.3.8
  + This is the last release on Github. Oslandia migrates from GitHub to GitLab:
  https://oslandia.com/en/2020/06/19/en-oslandia-migrates-from-github-to-gitlab/
  Next iteration of package will be based on gitlab.
  + Changes:
  * Fix CMake scripts so that SFCGAL_USE_STATIC_LIBS works properly again
  * Fix for divide by zero error in triangulatePolygon3D
  * Replace of auto_ptr with unique_ptr and move to c++14
  * Add implementation of Geometry::operator=
  * Fix CGAL v4.7 compatibility
  * add pkg-config descriptor file
  * Remove libtoolize
  * Add point_m and is_measured to c api
  * Fix SFCGAL with CGAL 5 (and GMPXX issues)
  * Add covers and covers3D to c api
  * Add documentation to SFCGAL::algorithm::extrude
  * Add 3D linear referencing / LineSubString and Fix built with MSCV 14
    and export to C API
  * Fix CAPI export symbol for windows
  * Update and fix documentation #138
* Sun Nov  3 2019 Bruno Friedmann <bruno@ioda-net.ch>
- After fixing repository for openscrenegraph, use pkgconfig form
  for buildrequires
* Mon Sep 23 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Use libOpenSceneGraph-devel pkgconfig form doesn't resolv for 15.1
- Don't use restricted x86-64 form of cmake
* Sun Sep 22 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.3.7
  + Fix compilation with CGAL 4.14 fix #188
  + Build Triangulation even with intersecting constraint edges
  + Fix C API headers
- Previous release
  + 1.3.6
    + Get rid of boost date_time dependency
    + Fix some implicit switch/case fallthrough
    + Sync with CGAL 4.13 and prepare for CGAL 4.14
    + Fix a memory leak in extrude C API (fix #179)
    + Remove Nef polyhedra inclusion
    + Intersection: Fix lexicographic order of coordinates (fix #171)
  + 1.3.5 : Fix 1.3.4 link issues
  + 1.3.4 Fix postgis build issue. fix wrong version number in 1.3.3
  + 1.3.3 Fix compilation + tests with cgal 4.11 (bogus version)
  + 1.3.2 Fix compilation with minimal needed CGAL 4.10
- Packaging
  + spec-cleaner to renew the spec
  + Fix build error with clang -ftlo flag to nil
  + Remove unsupported flag in clang -frounding-math
  + Remove obsolete build condition
  + Remove obsolete BuildRequires, adjust minimal version
  + Remove 5c495ce.patch merged upstream
  + Modify source url to have %%{name}-%%{version} as tar.gz
* Sun Feb 11 2018 bruno@ioda-net.ch
- Packaging :
  + Add BuildRequires Mesa-libGL-devel not autoresolved in Leap 15
  + Add 5c495ce.patch Fix build when CGAL is compiled with GMPXX
  + Remove -fstack-clash-protection existing on 42.3 %%cmake macro.
    But clang doesn't know this flag (Fix 42.3 builds)
  + Order cmake -D
* Thu Oct 12 2017 bruno@ioda-net.ch
- Update to 1.3.2 version but only for Tumbleweed.
  + Fixes for building with cgal 4.10.1+
- Update to 1.3.1 version but only for Leap 42.
  + Add a SFCGAL-osg library for OSG specific functions
    Fix C API geometry_is_planar
    Fix Doxygen script
- Packaging :
  + Use %%if around version to have a build on both case Leap & TW
  + sfcgal upstream 1.3.2 build only with cgal 4.10.1+ target TW
  + sfcgal upstream 1.3.1 build only with cgal < 4.10 target Leap
  + Remove conditionnal -fpie flag for 13.1
  + Remove merged patch upstream_fixes_post130.patch
  + Add missing libboost-*-devel for TW
  + Add -fpie for clang linker
* Mon Feb 13 2017 bruno@ioda-net.ch
- Packaging :
  + Add withosgd to exclude arch problematic with openscenegraph
    for the moment only i586 and x86_64 are build with.
  + Add upstream_fixes_post130.patch to be able to choose when we
    depend on openscenegraph.
  + Change for TW the new boost-devel way
* Sat Apr 23 2016 bruno@ioda-net.ch
- Update to new bug-fix release 1.3.0
  Add a validity flag to geometries
  Add an option to straight skeleton to return the distance to
  borders
  Add sfcgal_geometry_is_valid_detail to the C API
  Remove grid and ASC reader
  Remove the viewer
  Fix compilation issue with boost 1.60 (#119)
  Fix WKT parsing issues (#81 #117)
  Retain bisectors of narrow angles in MedialAxis output
* Mon Mar 14 2016 bruno@ioda-net.ch
- bypass bug 927268 for PowerPC if clang is used above in place of
  gcc. Fix powerpc builds
* Sun Mar 13 2016 bruno@ioda-net.ch
- Added flags to override failing %%cmake macro with 13.2
  - DCMAKE_USER_MAKE_RULES_OVERRIDE=OFF \
  - DCMAKE_CXX_COMPILER="clang++" \
  - DCMAKE_C_COMPILER="clang" \
- clang allow building with less memory oom
* Fri Feb 26 2016 bruno@ioda-net.ch
- Update dates + force rebuild on 13.2 i586
* Thu Feb 25 2016 bruno@ioda-net.ch
- Renable the examples, we got a patch for boost 1.60
* Tue Feb 23 2016 zaitor@opensuse.org
- Rename _constraint to _constraints, so that it is actually taken
  into account by the obs.
* Sun Nov 29 2015 guillaume@opensuse.org
- Update to v1.2.2
* Sat Sep 26 2015 mpluskal@suse.com
- Update project and download url
- Fully use %%cmake macros
- Cleanup spec file with spec-cleaner
* Sat Sep 26 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- upstream updated bugfix release 1.2.0 2015-09-18
  - Improve the computation speed of straight skeletons by using
    inexact construction kernel
  - Add a new function approximateMedialAxis
  - Fix an invalidity case (polygon degenerated to a point) #108
  - Fix compilation issues with boost 1.58
  - Add Travis support
* Mon Mar  2 2015 bruno@ioda-net.ch
- upstream updated bugfix release 1.1.0 2015-01-14
  - New spatial operation Union(geom, geom)
  and Difference(geom, geom).
  - Exposed Volume(geom) in C api and added output with a
  decimal representation sfcgal_geometry_as_text_decim
  (thanks @matze09)
  - Minor bug fixes.
- packaging :
  spec-cleaner (date,name,order)
* Sun Nov 23 2014 bruno@ioda-net.ch
- upstream updated release 1.0.5
    Fix validity check message when converting to 2D
    Fix a polygon orientation test (postgis bug #2818)
    Fix a bug in plane3D
    Add better handling of EMPTY in collections
    Compilation issues:
    Fix a cmake issue (FindOsgQT)
    Fix compilation issue with gcc < 4.5
    Avoid osg dependency when viewer is not built
    Fix postgresql include directory
    Add detection of lib64 directories
- packaging :
  removed obsolete merged upstream patches
    sle-error-typename-outside-of-template.patch
    0001-Small-typo-changed-requiered-to-required.patch
    0007-fixes-polygon-triangulation.patch
    0004-Replace-lib-by-CMAKE_INSTALL_LIBDIR-in-installation-.patch
    0002-Add-VERSION-and-SOVERSION-properties.patch
    0003-Add-detection-of-lib-lib64-directory.patch
    0005-Added-FindPostgreSQL.cmake-macros.patch
    0006-fixed-unfindable-postgres-header-cmake-variable.patch
  use of %%cmake macro.
* Thu Jun  5 2014 bruno@ioda-net.ch
- packaging: Build for sle adding specific patch for typename
  sle-error-typename-outside-of-template.patch
* Sat May 24 2014 bruno@ioda-net.ch
- packaging: spec-cleaner, remove used comments, coherent usage
  of -jobs.
* Wed Apr 30 2014 bruno@ioda-net.ch
- packaging : use advanced security flags only on supported version
  >=1310
* Tue Apr 29 2014 bruno@ioda-net.ch
- packaging : respect lib policy
- sources : added upstream patches fixing triangulation & build
  issues with postgresql, lib(64), soversion
  +0001-Small-typo-changed-requiered-to-required.patch
  +0002-Add-VERSION-and-SOVERSION-properties.patch
  +0003-Add-detection-of-lib-lib64-directory.patch
  +0004-Replace-lib-by-CMAKE_INSTALL_LIBDIR-in-installation-.patch
  +0005-Added-FindPostgreSQL.cmake-macros.patch
  +0006-fixed-unfindable-postgres-header-cmake-variable.patch
  +0007-fixes-polygon-triangulation.patch
* Fri Jan  3 2014 bruno@ioda-net.ch
- Added patch for upstream issue 37 fixing soname & soversion
  SFCGAL_issue37.patch
- packaging : we build the viewer and the example programs
* Sun Dec 22 2013 bruno@ioda-net.ch
- Upstream 1.0.4 update
- Commented include CGAL we use CGAL 4.3 now
* Thu Nov 14 2013 bruno@ioda-net.ch
- First build & packaging version
